| Title: | Model Wrappers for Tree-Based Models |
|---|---|
| Description: | Bindings for additional tree-based model engines for use with the 'parsnip' package. Models include gradient boosted decision trees with 'LightGBM' (Ke et al, 2017.), conditional inference trees and conditional random forests with 'partykit' (Hothorn and Zeileis, 2015. and Hothorn et al, 2006. <doi:10.1198/106186006X133933>), and accelerated oblique random forests with 'aorsf' (Jaeger et al, 2022 <doi:10.5281/zenodo.7116854>). |
| Authors: | Daniel Falbel [aut], Athos Damiani [aut], Roel M. Hogervorst [aut] (ORCID: <https://orcid.org/0000-0001-7509-0328>), Max Kuhn [aut] (ORCID: <https://orcid.org/0000-0003-2402-136X>), Simon Couch [aut] (ORCID: <https://orcid.org/0000-0001-5676-5107>), Emil Hvitfeldt [aut, cre] (ORCID: <https://orcid.org/0000-0002-0679-1945>), Posit Software, PBC [cph, fnd] (ROR: <https://ror.org/03wc8by49>) |
| Maintainer: | Emil Hvitfeldt <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.4.1.9000 |
| Built: | 2026-05-22 00:06:48 UTC |
| Source: | https://github.com/tidymodels/bonsai |
Bindings for additional tree-based model engines for use with the 'parsnip' package. Models include gradient boosted decision trees with 'LightGBM' (Ke et al, 2017.), conditional inference trees and conditional random forests with 'partykit' (Hothorn and Zeileis, 2015. and Hothorn et al, 2006. doi:10.1198/106186006X133933), and accelerated oblique random forests with 'aorsf' (Jaeger et al, 2022 doi:10.5281/zenodo.7116854).
Maintainer: Emil Hvitfeldt [email protected] (ORCID)
Authors:
Daniel Falbel [email protected]
Athos Damiani [email protected]
Roel M. Hogervorst [email protected] (ORCID)
Max Kuhn [email protected] (ORCID)
Simon Couch [email protected] (ORCID)
Other contributors:
Posit Software, PBC (ROR) [copyright holder, funder]
Useful links:
Report bugs at https://github.com/tidymodels/bonsai/issues